@@ -1,7 +1,7 @@
 /*
  *  callbacks.c - functions to handle GUI events.
  *	part of galculator
- *  	(c) 2002-2007 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2009 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -91,7 +91,7 @@ on_about_activate                     (GtkMenuItem     *menuitem,
 	gtk_label_set_justify (about_label, GTK_JUSTIFY_CENTER);
 	about_text = g_strdup_printf (_("<span size=\"x-large\" weight=\"bold\">%s v%s</span>\n\
 <span size=\"large\">a GTK 2 based scientific calculator</span>\n\n\
-(c) 2002-2007 by Simon Floery (chimaira@users.sf.net)"), PROG_NAME, VERSION);
+(c) 2002-2009 by Simon Floery (chimaira@users.sf.net)"), PROG_NAME, VERSION);
 	gtk_label_set_markup (about_label, \
 		about_text);
 	gtk_widget_show (about_dialog);
@@ -140,7 +140,7 @@ on_operation_button_clicked            (GtkToggleButton       *button,
 	button_activation (button);
 	
 	if (current_status.notation == CS_FORMULA) {
-		if (strcmp (gtk_widget_get_name ((GtkWidget *) button), "button_enter") == 0)
+		if (strcmp (gtk_widget_get_name((GtkWidget *) button), "button_enter") == 0)
 			ui_formula_entry_activate();
 		/* as long as we don't support string operation ids, we take
 		 * operation char. take this later on:
@@ -148,15 +148,15 @@ on_operation_button_clicked            (GtkToggleButton       *button,
 		 *	g_object_get_data (G_OBJECT (button), "display_string"));
 		 */
 		else {
-			operation_string = g_strdup_printf ("%c", (int) g_object_get_data (
-				G_OBJECT (button), "operation"));
+			operation_string = g_strdup_printf("%c", GPOINTER_TO_INT(g_object_get_data (
+				G_OBJECT (button), "operation")));
 			ui_formula_entry_insert (operation_string);
 			g_free(operation_string);
 		}
 		return;
 	}
 	
-	current_token.operation = (int) g_object_get_data (G_OBJECT (button), "operation");
+	current_token.operation = GPOINTER_TO_INT(g_object_get_data(G_OBJECT (button), "operation"));
 	/* current number, get it from the display! */
 	current_token.number = display_result_get_double (current_status.number);
 	current_token.func = NULL;
@@ -502,6 +502,8 @@ on_basic_mode_activate (GtkMenuItem     *menuitem,
 	gtk_widget_set_sensitive (menu_item, TRUE);
 	menu_item = glade_xml_get_widget (main_window_xml, "notation");
 	gtk_widget_set_sensitive (menu_item, TRUE);
+	
+	set_window_size_minimal();
 }
 
 void
@@ -562,6 +564,8 @@ on_scientific_mode_activate (GtkMenuItem *menuitem,
 	gtk_widget_set_sensitive (menu_item, TRUE);
 	menu_item = glade_xml_get_widget (main_window_xml, "notation");
 	gtk_widget_set_sensitive (menu_item, TRUE);
+	
+	set_window_size_minimal();
 }	
 
 void
@@ -587,6 +591,8 @@ on_paper_mode_activate (GtkMenuItem *menuitem,
 	gtk_widget_set_sensitive (menu_item, FALSE);
 	menu_item = glade_xml_get_widget (main_window_xml, "notation");
 	gtk_widget_set_sensitive (menu_item, FALSE);
+	
+	set_window_size_minimal();
 }	
 
 void
@@ -802,7 +808,11 @@ on_show_menubar1_activate              (GtkMenuItem     *menuitem,
 	GtkWidget	*menu_item;
 	
 	prefs.show_menu = gtk_check_menu_item_get_active ((GtkCheckMenuItem *) menuitem);;
-	set_widget_visibility (main_window_xml, "menubar", prefs.show_menu);
+#ifdef WITH_HILDON
+	set_widget_visibility (main_window_xml, "main_menu", prefs.show_menu);
+#else
+ 	set_widget_visibility (main_window_xml, "menubar", prefs.show_menu);
+#endif
 	/* in case this cb is called by the right button mouse click menu */
 	menu_item = glade_xml_get_widget (main_window_xml, "show_menubar1");
 	gtk_check_menu_item_set_active ((GtkCheckMenuItem *) menu_item, prefs.show_menu);
@@ -871,7 +881,11 @@ void on_prefs_show_menu_toggled (GtkToggleButton *togglebutton,
 	GtkCheckMenuItem		*show_menubar_item;
 	
 	prefs.show_menu = gtk_toggle_button_get_active (togglebutton);
-	set_widget_visibility (main_window_xml, "menubar", prefs.show_menu);
+#ifdef WITH_HILDON
+	set_widget_visibility (main_window_xml, "main_menu", prefs.show_menu);
+#else
+ 	set_widget_visibility (main_window_xml, "menubar", prefs.show_menu);
+#endif
 	show_menubar_item = (GtkCheckMenuItem *) glade_xml_get_widget (main_window_xml, "show_menubar1");
 	gtk_check_menu_item_set_active (show_menubar_item, prefs.show_menu);
 }
@@ -887,16 +901,23 @@ void on_prefs_button_width_changed (GtkSpinButton *spinbutton,
 					GtkScrollType arg1,
 					gpointer user_data)
 {
-	prefs.button_width = (int) gtk_spin_button_get_value (spinbutton);
-	set_all_buttons_size (prefs.button_width, prefs.button_height);
+	int new_button_width = (int) gtk_spin_button_get_value (spinbutton);
+	
+	if (new_button_width != prefs.button_width) {
+		prefs.button_width = new_button_width;
+		set_all_buttons_size (prefs.button_width, prefs.button_height);
+	}
 }
 
 void on_prefs_button_height_changed (GtkSpinButton *spinbutton,
 					GtkScrollType arg1,
 					gpointer user_data)
 {	
-	prefs.button_height = (int) gtk_spin_button_get_value (spinbutton);
-	set_all_buttons_size (prefs.button_width, prefs.button_height);
+	int new_button_height = (int) gtk_spin_button_get_value (spinbutton);
+	if (new_button_height != prefs.button_height) {
+		prefs.button_height = new_button_height;
+		set_all_buttons_size (prefs.button_width, prefs.button_height);
+	}
 }
 
 /*
@@ -908,7 +929,7 @@ void user_functions_menu_handler (GtkMenuItem *menuitem, gpointer user_data)
 	int 			index;
 	s_flex_parser_result	result;
 	
-	index = (int) user_data;
+	index = GPOINTER_TO_INT(user_data);
 	result = compute_user_function (
 		user_function[index].expression, user_function[index].variable,
 		display_result_get());
@@ -995,9 +1016,7 @@ void ms_menu_handler (GtkMenuItem *menuitem, gpointer user_data)
 	current_status.calc_entry_start_new = TRUE;
 }
 
-void
-on_ms_button_clicked (GtkToggleButton       *button,
-			gpointer user_data)
+void on_ms_button_clicked (GtkToggleButton *button, gpointer user_data)
 {
 	GtkWidget	*menu;
 	
@@ -1021,9 +1040,7 @@ void mr_menu_handler (GtkMenuItem *menuitem, gpointer user_data)
 	current_status.calc_entry_start_new = TRUE;
 }
 
-void
-on_mr_button_clicked             (GtkToggleButton       *button,
-				gpointer         user_data)
+void on_mr_button_clicked (GtkToggleButton *button, gpointer user_data)
 {
 	GtkWidget	*menu;;
 	
@@ -1043,9 +1060,7 @@ void mplus_menu_handler (GtkMenuItem *menuitem, gpointer user_data)
 	memory.data[index] += display_result_get_double(current_status.number);
 }
 
-void
-on_mplus_button_clicked             (GtkToggleButton       *button,
-				gpointer         user_data)
+void on_mplus_button_clicked (GtkToggleButton *button, gpointer user_data)
 {
 	GtkWidget	*menu;
 	
@@ -1516,9 +1531,15 @@ void on_togglebutton_released (GtkToggleButton *togglebutton,
 	gtk_toggle_button_set_active (togglebutton, FALSE);
 }
 
+/* this function was the signal handler for 'check-resize' of main_window.
+ * I see no reason to have it further. so i unlinked it. the code is here
+ * if we need it some later time.
+ */
 void on_main_window_check_resize (GtkContainer *container,
                                             gpointer user_data)
 {
+	fprintf (stderr, _("[%s] on_main_window_check_resize should not get called. %s\n"), PROG_NAME, BUG_REPORT);
+	
 	static gboolean		itsme=FALSE;
 	
 	/* only in classic views this function may take effect */
