@@ -1,7 +1,7 @@
 /*
  *  config_file.c - manages config file access.
  *	part of galculator
- *  	(c) 2002-2006 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2009 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -41,21 +41,21 @@
 
 s_preferences prefs;
 static s_prefs_entry prefs_list[53] = {
-	{"display_bkg_color", &(prefs.bkg_color), STRING, "prefs_bkg_color", set_button_color},
-	{"display_result_font", &(prefs.result_font), STRING, "prefs_result_font", set_button_label},
-	{"display_result_color", &(prefs.result_color), STRING, "prefs_result_color", set_button_color},
-	{"display_stack_font", &(prefs.stack_font), STRING, "prefs_stack_font", set_button_label},
-	{"display_stack_color", &(prefs.stack_color), STRING, "prefs_stack_color", set_button_color},
-	{"display_module_font", &(prefs.mod_font), STRING, "prefs_mod_font", set_button_label},
-	{"display_module_active_color", &(prefs.act_mod_color), STRING, "prefs_act_mod_color", set_button_color},
-	{"display_module_inactive_color", &(prefs.inact_mod_color), STRING, "prefs_inact_mod_color", set_button_color},
+	{"display_bkg_color", &(prefs.bkg_color), STRING, "prefs_bkg_color_button", set_button_color},
+	{"display_result_font", &(prefs.result_font), STRING, "prefs_result_font", set_button_font},
+	{"display_result_color", &(prefs.result_color), STRING, "prefs_result_color_button", set_button_color},
+	{"display_stack_font", &(prefs.stack_font), STRING, "prefs_stack_font", set_button_font},
+	{"display_stack_color", &(prefs.stack_color), STRING, "prefs_stack_color_button", set_button_color},
+	{"display_module_font", &(prefs.mod_font), STRING, "prefs_mod_font", set_button_font},
+	{"display_module_active_color", &(prefs.act_mod_color), STRING, "prefs_act_mod_color_button", set_button_color},
+	{"display_module_inactive_color", &(prefs.inact_mod_color), STRING, "prefs_inact_mod_color_button", set_button_color},
 	{"display_module_number", &(prefs.vis_number), BOOLEAN, "prefs_vis_number", set_checkbutton},
 /*10*/	{"display_module_angle", &(prefs.vis_angle), BOOLEAN, "prefs_vis_angle", set_checkbutton},
 	{"display_module_notation", &(prefs.vis_notation), BOOLEAN, "prefs_vis_notation", set_checkbutton},
 	{"display_module_arith", &(prefs.vis_arith), BOOLEAN, "prefs_vis_arith", set_checkbutton},
 	{"display_module_open", &(prefs.vis_bracket), BOOLEAN, "prefs_vis_bracket", set_checkbutton},
 	{"custom_button_font", &(prefs.custom_button_font), BOOLEAN, "prefs_custom_button_font", set_checkbutton},
-	{"button_font", &(prefs.button_font), STRING, "prefs_button_font", set_button_label},
+	{"button_font", &(prefs.button_font), STRING, "prefs_button_font", set_button_font},
 	{"button_width", &(prefs.button_width), INTEGER, "prefs_button_width", set_spinbutton},
 	{"button_height", &(prefs.button_height), INTEGER, "prefs_button_height", set_spinbutton},
 	{"function_button_group", &(prefs.vis_funcs), BOOLEAN, NULL, NULL},
@@ -307,7 +307,7 @@ void config_file_set_constants (char *line)
 	value++;
 	desc = g_strstrip(desc);
 	name = g_strstrip(name);
-	value = g_strstrip(value);
+	value = g_strstrip(value);	
 	/* allowing desc and name to be "" */
 	if (strlen(value) == 0) return;
 	nr_consts++;
