@@ -1,7 +1,7 @@
 /*
  *  display.c - code for this nifty display.
  *	part of galculator
- *  	(c) 2002-2007 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2009 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -752,6 +752,8 @@ static char *display_get_line (int line_nr)
 {
 	GtkTextIter 	start, end;
 	
+	if (prefs.mode == PAPER_MODE) return NULL;
+	
 	display_get_line_iters (buffer, line_nr, &start, &end);
 	/* DISPLAY RESULT GET */
 	return string_del_separator(gtk_text_buffer_get_text (buffer, &start, &end, TRUE), get_sep_char(current_status.number));
@@ -780,8 +782,6 @@ double display_result_get_double (int number_base_status)
 
 void display_append_e (GtkToggleButton *button)
 {
-	char			*display_value;
-
 	/* we have kind of a shortcut. we don't set to 0e+ but 1e+ */
 	if (current_status.number != CS_DEC) return;
 	if ((current_status.calc_entry_start_new == FALSE) && 
@@ -791,9 +791,9 @@ void display_append_e (GtkToggleButton *button)
 			display_get_line_end_iter (buffer, display_result_line, &end);
 			gtk_text_buffer_insert_with_tags_by_name (buffer, &end, "e+", -1, "result", NULL);
 			*/
-			display_value = g_strdup_printf ("%se+", display_result_get());
-			display_result_set (display_value, FALSE, -1);
-			g_free (display_value);
+			char *display_string = g_strdup_printf ("%se+", display_result_get());
+			display_result_set (display_string, FALSE, -1);
+			g_free (display_string);
 		}
 	} else {
 		display_result_set ("1e+", TRUE, 1.);
@@ -809,16 +809,21 @@ void display_result_toggle_sign (GtkToggleButton *button)
 	if (current_status.number != CS_DEC) return;
 	result_field = display_result_get();
 	/* if there is no e? we toggle the leading sign, otherwise the sign after e */
-	if ((e_pointer = strchr (result_field, 'e')) == NULL) {
+	if ((e_pointer = strchr (result_field, 'e')) == NULL || current_status.calc_entry_start_new) {
 		if (*result_field == '-') g_stpcpy (result_field, result_field + sizeof(char));
 		else if (strcmp (result_field, "0") != 0)
 			result_field = g_strdup_printf ("-%s", result_field);
+		display_value *= (-1);
 	} else {
 		if (*(++e_pointer) == '-') *e_pointer = '+';
 		else *e_pointer = '-';
+		/* this has to be done by retrieving the exponent. believe me.
+		 * (try 0.001e-3 for example).
+		 */
+		if (strlen(e_pointer) > 1) 
+			display_value *= pow(10., 2*string2double(e_pointer, CS_DEC));
 	}
 	display_result_set (result_field, FALSE, -1.);
-	display_value *= (-1);
 	g_free (result_field);
 }
 
@@ -857,6 +862,7 @@ void display_result_getset ()
 	char	**stack;
 	
 	if (prefs.mode == PAPER_MODE) return;
+	
 	result = display_result_get();
 	stack = display_stack_get_yzt();
 	display_result_set(result, FALSE, -1);
