@@ -1,7 +1,7 @@
 /*
  *  display.h
  *	part of galculator
- *  	(c) 2002-2007 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2009 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,9 +26,9 @@
 
 #define DISPLAY_MARK_NUMBER		"mark_number"
 #define DISPLAY_MARK_ANGLE		"mark_angle"
-#define DISPLAY_MARK_NOTATION		"mark_notation"
+#define DISPLAY_MARK_NOTATION	"mark_notation"
 #define DISPLAY_MARK_ARITH		"mark_arith"
-#define DISPLAY_MARK_BRACKET		"mark_bracket"
+#define DISPLAY_MARK_BRACKET	"mark_bracket"
 
 #define DISPLAY_MODULES_DELIM 		"   "
 
@@ -51,13 +51,13 @@ extern gboolean calc_entry_start_new;
 /* general */
 
 
-gboolean on_textview_button_press_event (GtkWidget *widget,
-                                        GdkEventButton *event,
-                                        gpointer user_data);
-void on_textview_selection_received (GtkWidget *widget,
-                                            GtkSelectionData *data,
-                                            guint time,
-                                            gpointer user_data);
+G_MODULE_EXPORT gboolean on_textview_button_press_event (GtkWidget *widget,
+							GdkEventButton *event,
+							gpointer user_data);
+G_MODULE_EXPORT void on_textview_selection_received (GtkWidget *widget,
+							GtkSelectionData *data,
+							guint time,
+							gpointer user_data);
 void display_init ();
 void display_update_modules ();
 void display_option_label_set (GtkLabel *label);
