@@ -1,7 +1,7 @@
 /*
  *  general_functions.c - this and that.
  *	part of galculator
- *  	(c) 2002-2007 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2009 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -296,7 +296,7 @@ void set_entry (GladeXML *xml, char *entry_name, void *entry_text)
 {
 	GtkEntry	*entry;
 	char 		**string_var;
-	
+
 	string_var = entry_text;	
 	entry = (GtkEntry *) glade_xml_get_widget (xml, entry_name);
 	if (entry) gtk_entry_set_text (entry, *string_var);	
@@ -322,7 +322,11 @@ void apply_preferences (s_preferences prefs)
 	GtkWidget	*menu_item;
 
 	/* not view specific */
-	set_widget_visibility (main_window_xml, "menubar", prefs.show_menu);
+#ifdef WITH_HILDON
+	set_widget_visibility (main_window_xml, "main_menu", prefs.show_menu);
+#else
+ 	set_widget_visibility (main_window_xml, "menubar", prefs.show_menu);
+#endif
 	menu_item = glade_xml_get_widget (main_window_xml, "show_menubar1");
 	gtk_check_menu_item_set_active ((GtkCheckMenuItem *) menu_item, prefs.show_menu);
 
@@ -403,11 +407,25 @@ void activate_menu_item (char *item_name)
 
 char *get_display_number_string (double value, int base)
 {
-	char 	*string_value;
+	char 	*string_value, *string_value0, *string_value1;
 	
 	switch (base) {
 		case CS_DEC:
-			string_value = g_strdup_printf ("%.*g", get_display_number_length(current_status.number), value);
+			/* this is a work around for numerical issues. When
+			 * get_display_number_length(current_status.number) = 12, 
+			 * 1000.11 - 1000.10 returns 0.0099999999999999. We round for two
+			 * different precision levels and check whether one result is
+			 * significantly shorter than the other.
+			 */
+			string_value0 = g_strdup_printf("%.*g", get_display_number_length(current_status.number) - 1, value);
+			string_value1 = g_strdup_printf("%.*g", get_display_number_length(current_status.number), value);
+			if (strlen(string_value0) + 1 < strlen(string_value1)) {
+				string_value = string_value0;
+				g_free(string_value1);
+			} else {
+				string_value = string_value1;
+				g_free(string_value0);
+			}
 			break;
 		case CS_HEX:
 			string_value = ftoax (value, 16, prefs.hex_bits, prefs.hex_signed);
@@ -553,7 +571,9 @@ double string2double (char *string, int number_base)
 		case CS_DEC:
 			ret_val = strtod(string, &end_ptr);
 			if (*end_ptr != '\0')
-				fprintf (stderr, _("[%s] failed to convert %s to a number properly in function \"string2double\". Have you changed your locales? %s\n"), PACKAGE, string, BUG_REPORT);
+				fprintf (stderr, _("[%s] failed to convert %s to a number properly \
+in function \"string2double\". Have you changed your locales? \
+Deleting your configuration file might solve this problem. %s\n"), PACKAGE, string, BUG_REPORT);
 			return ret_val;
 			break;
 		case CS_HEX:
@@ -661,9 +681,9 @@ void set_button_label_and_tooltip (GladeXML *xml, char *button_name,
 	w = glade_xml_get_widget (xml, button_name);
 	if (w) {
 		gtk_button_set_label ((GtkButton *)w, label);
+		
 		tooltip_data = gtk_tooltips_data_get (w);
-		g_free (tooltip_data->tip_text);
-		tooltip_data->tip_text = g_strdup (tooltip);
+		gtk_tooltips_set_tip(tooltip_data->tooltips, w, tooltip, tooltip_data->tip_private);
 	}
 }
 
@@ -802,7 +822,7 @@ char get_sep_char (int number_base)
 
 void prefs_sep_char_changed (GtkEditable *editable, char *prefs_sep, int number_base)
 {
-	char 	*sep, *result, **stack;
+	char 	*sep, *result=NULL, **stack=NULL;
 	
 	sep = gtk_editable_get_chars (editable, 0, -1);
 	if (strlen(sep) > 0) {
@@ -812,16 +832,22 @@ void prefs_sep_char_changed (GtkEditable *editable, char *prefs_sep, int number_
 			!isascii(*sep))
 			gtk_editable_delete_text (editable, 0, -1);
 		else {
-			result = display_result_get();
-			stack = display_stack_get_yzt();
+			if (prefs.mode != PAPER_MODE) {
+				result = display_result_get();
+				stack = display_stack_get_yzt();				
+			}
+			
 			if (prefs_sep) g_free (prefs_sep);
 			prefs_sep = g_strdup(sep);
-			if (number_base == current_status.number) {
-				display_result_set(result, FALSE, -1.);
-				display_stack_set_yzt(stack);
+			
+			if (prefs.mode != PAPER_MODE && result && stack) {
+				if (number_base == current_status.number) {
+					display_result_set(result, FALSE, -1.);
+					display_stack_set_yzt(stack);
+				}
+				g_free (result);
+				g_free (stack);
 			}
-			g_free (result);
-			g_free (stack);
 		}
 	}
 	g_free (sep);	
@@ -861,3 +887,16 @@ void change_option (int new_status, int opt_group)
 	}
 	current_status.calc_entry_start_new = TRUE;
 }
+
+/*
+ * after changing for example the view from scientific to basic, call this
+ * function to resize the window.
+ */
+void set_window_size_minimal()
+{
+	GtkWidget	*main_window=NULL;
+	
+	main_window = glade_xml_get_widget (main_window_xml, "main_window");
+	if (main_window != NULL)
+		gtk_window_resize ((GtkWindow *)gtk_widget_get_toplevel(main_window), 1, 1);
+}
