@@ -1,7 +1,7 @@
 /*
  *  ui.c - general user interface code.
  *	part of galculator
- *  	(c) 2002-2007 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2009 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -302,6 +302,17 @@ GtkWidget *ui_main_window_create ()
 	return glade_xml_get_widget (main_window_xml, "main_window");
 }
 
+#ifdef WITH_HILDON
+void create_hildon_menu (HildonWindow *main_window)
+{
+    GtkWidget *main_menu;
+    
+    main_menu = glade_xml_get_widget (main_window_xml, "main_menu");
+    hildon_window_set_menu(HILDON_WINDOW(main_window), GTK_MENU(main_menu));
+    gtk_widget_show_all(GTK_WIDGET(main_menu));
+}
+#endif
+
 /* ui_main_window_set_dispctrl. we can't (un-)hide the dispctrl buttons as they
  * have the same key accelerators and thus only one button group would get
  * activated.
@@ -599,7 +610,11 @@ void set_all_buttons_size (int width, int height)
 	
 	size.width = width;
 	size.height = height;
+		
 	set_all_buttons_property (set_table_child_size, (gpointer) &size);
+		
+	gtk_window_resize ((GtkWindow *) gtk_widget_get_toplevel(
+			(GtkWidget *) glade_xml_get_widget (main_window_xml, "main_window")), 1, 1);
 }
 
 void set_all_normal_buttons_tip ()
@@ -900,13 +915,14 @@ GtkWidget *ui_pref_dialog_create ()
 	prefs_list = config_file_get_prefs_list();
 	while (prefs_list[counter].key != NULL) {
 		if (prefs_list[counter].set_handler != NULL) {
-			prefs_list[counter].set_handler (prefs_xml,
+			prefs_list[counter].set_handler (
+				prefs_xml,
 				prefs_list[counter].widget_name,
 				prefs_list[counter].variable);
 		}
 		counter++;
 	}
-	
+
 	w = glade_xml_get_widget (prefs_xml, "prefs_button_font_label");
 	gtk_widget_set_sensitive (w, prefs.custom_button_font);
 	
